@@ -111,8 +111,9 @@ _current_view()
     g_warning("can not get current view (%s)\n", error->message);
     g_error_free(error);
     error = NULL;
-    return 0;
+    current_view = 0;
   }
+  g_object_unref(client);
   return current_view;
 }
 
@@ -133,8 +134,9 @@ _active_views()
     g_warning("can not get list of active views (%s)\n", error->message);
     g_error_free(error);
     error = NULL;
-    return NULL;
+    active_views = NULL;
   }
+  g_object_unref(client);
   return active_views;
 }
 
